@@ -6,7 +6,7 @@
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -25,9 +25,9 @@ import org.apache.commons.net.DatagramSocketClient;
 
 /**
  * The DaytimeUDPClient class is a UDP implementation of a client for the Daytime protocol described in RFC 867. To use the class, merely open a local datagram
- * socket with {@link org.apache.commons.net.DatagramSocketClient#open open } and call {@link #getTime getTime } to retrieve the daytime string, then call
- * {@link org.apache.commons.net.DatagramSocketClient#close close } to close the connection properly. Unlike
- * {@link org.apache.commons.net.daytime.DaytimeTCPClient}, successive calls to {@link #getTime getTime } are permitted without re-establishing a connection.
+ * socket with {@link org.apache.commons.net.DatagramSocketClient#open open} and call {@link #getTime getTime} to retrieve the daytime string, then call
+ * {@link org.apache.commons.net.DatagramSocketClient#close close} to close the connection properly. Unlike
+ * {@link org.apache.commons.net.daytime.DaytimeTCPClient}, successive calls to {@link #getTime getTime} are permitted without re-establishing a connection.
  * That is because UDP is a connectionless protocol and the Daytime protocol is stateless.
  *
  * @see DaytimeTCPClient
@@ -47,7 +47,17 @@ public final class DaytimeUDPClient extends DatagramSocketClient {
     private final byte[] timeData = new byte[256];
 
     /**
-     * Shorthand for <code>getTime(host, DaytimeUDPClient.DEFAULT_PORT);</code>
+     * Constructs a new instance.
+     */
+    public DaytimeUDPClient() {
+        // empty
+    }
+
+    /**
+     * Gets the time string from the specified server and port and returns it.
+     * <p>
+     * Shorthand for {@code getTime(host, DaytimeUDPClient.DEFAULT_PORT);}
+     * </p>
      *
      * @param host the host
      * @return the time
