@@ -6,7 +6,7 @@
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -18,9 +18,8 @@
 package org.apache.commons.net.examples.nntp;
 
 import java.io.IOException;
-import java.io.PrintWriter;
 
-import org.apache.commons.net.PrintCommandListener;
+import org.apache.commons.net.examples.PrintCommandListeners;
 import org.apache.commons.net.nntp.Article;
 import org.apache.commons.net.nntp.NNTPClient;
 import org.apache.commons.net.nntp.NewsgroupInfo;
@@ -47,7 +46,7 @@ public class ExtendedNNTPOps {
 
     public ExtendedNNTPOps() {
         client = new NNTPClient();
-        client.addProtocolCommandListener(new PrintCommandListener(new PrintWriter(System.out), true));
+        client.addProtocolCommandListener(PrintCommandListeners.sysOutPrintCommandListener());
     }
 
     private void demo(final String host, final String user, final String password) {
