@@ -6,7 +6,7 @@
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -38,6 +38,7 @@ import javax.net.ssl.SSLSocket;
 import javax.net.ssl.SSLSocketFactory;
 import javax.net.ssl.TrustManager;
 
+import org.apache.commons.io.IOUtils;
 import org.apache.commons.net.util.SSLContextUtils;
 import org.apache.commons.net.util.SSLSocketUtils;
 import org.apache.commons.net.util.TrustManagerUtils;
@@ -330,19 +331,14 @@ public class FTPSClient extends FTPClient {
     }
 
     /**
-     * Close open sockets.
+     * Closes sockets.
      *
-     * @param socket    main socket for proxy if enabled
-     * @param sslSocket ssl socket
-     * @throws IOException closing sockets is not successful
+     * @param socket    main socket for proxy if enabled.
+     * @param sslSocket SSL socket.
+     * @throws IOException closing sockets is not successful.
      */
     private void closeSockets(final Socket socket, final Socket sslSocket) throws IOException {
-        if (socket != null) {
-            socket.close();
-        }
-        if (sslSocket != null) {
-            sslSocket.close();
-        }
+        IOUtils.close(socket, sslSocket);
     }
 
     /**
@@ -372,9 +368,7 @@ public class FTPSClient extends FTPClient {
     @Override
     public void disconnect() throws IOException {
         super.disconnect();
-        if (plainSocket != null) {
-            plainSocket.close();
-        }
+        IOUtils.close(plainSocket);
         setSocketFactory(null);
         setServerSocketFactory(null);
     }
@@ -517,7 +511,8 @@ public class FTPSClient extends FTPClient {
      * <li>E - Confidential(SSL protocol only)</li>
      * <li>P - Private</li>
      * </ul>
-     * <b>N.B.</b> the method calls {@link #setSocketFactory(javax.net.SocketFactory)} and {@link #setServerSocketFactory(javax.net.ServerSocketFactory)}
+     * <strong>N.B.</strong> the method calls {@link #setSocketFactory(javax.net.SocketFactory)} and
+     * {@link #setServerSocketFactory(javax.net.ServerSocketFactory)}
      *
      * @param prot Data Channel Protection Level, if {@code null}, use {@link #DEFAULT_PROT}.
      * @throws SSLException If the server reply code does not equal {@code 200}.
@@ -555,21 +550,21 @@ public class FTPSClient extends FTPClient {
         if (idx == -1) {
             return null;
         }
-        // N.B. Cannot use trim before substring as leading space would affect the offset.
+        // Cannot use trim before substring as leading space would affect the offset.
         return reply.substring(idx + prefix.length()).trim();
     }
 
     /**
-     * Return AUTH command use value.
+     * Gets AUTH command use value.
      *
      * @return AUTH command use value.
      */
     public String getAuthValue() {
-        return this.auth;
+        return auth;
     }
 
     /**
-     * Returns the names of the cipher suites which could be enabled for use on this connection. When the underlying {@link Socket} is not an {@link SSLSocket}
+     * Gets the names of the cipher suites which could be enabled for use on this connection. When the underlying {@link Socket} is not an {@link SSLSocket}
      * instance, returns null.
      *
      * @return An array of cipher suite names, or {@code null}
@@ -582,7 +577,7 @@ public class FTPSClient extends FTPClient {
     }
 
     /**
-     * Returns the names of the protocol versions which are currently enabled for use on this connection. When the underlying {@link Socket} is not an
+     * Gets the names of the protocol versions which are currently enabled for use on this connection. When the underlying {@link Socket} is not an
      * {@link SSLSocket} instance, returns null.
      *
      * @return An array of protocols, or {@code null}
@@ -595,7 +590,7 @@ public class FTPSClient extends FTPClient {
     }
 
     /**
-     * Returns true if new SSL sessions may be established by this socket. When the underlying {@link Socket} instance is not SSL-enabled (i.e. an instance of
+     * Gets true if new SSL sessions may be established by this socket. When the underlying {@link Socket} instance is not SSL-enabled (i.e. an instance of
      * {@link SSLSocket} with {@link SSLSocket}{@link #getEnableSessionCreation()}) enabled, this returns False.
      *
      * @return true - Indicates that sessions may be created; this is the default. false - indicates that an existing session must be resumed.
@@ -627,7 +622,7 @@ public class FTPSClient extends FTPClient {
     }
 
     /**
-     * Returns true if the socket will require client authentication. When the underlying {@link Socket} is not an {@link SSLSocket} instance, returns false.
+     * Gets true if the socket will require client authentication. When the underlying {@link Socket} is not an {@link SSLSocket} instance, returns false.
      *
      * @return true - If the server mode socket should request that the client authenticate itself.
      */
@@ -640,8 +635,9 @@ public class FTPSClient extends FTPClient {
 
     /**
      * Gets the secure socket protocol to be used, e.g. SSL/TLS.
-     * @since 3.11.0
+     *
      * @return the protocol
+     * @since 3.11.0
      */
     protected String getProtocol() {
         return protocol;
@@ -650,8 +646,9 @@ public class FTPSClient extends FTPClient {
     /**
      * Gets the protocol versions. The {@link #getEnabledProtocols()} method gets the value from the socket while
      * this method gets its value from this instance's config.
-     * @since 3.11.0
+     *
      * @return a clone of the protocols, may be null
+     * @since 3.11.0
      */
     protected String[] getProtocols() {
         return protocols == null ? null : protocols.clone();
@@ -660,8 +657,9 @@ public class FTPSClient extends FTPClient {
     /**
      * Gets the cipher suites. The {@link #getEnabledCipherSuites()} method gets the value from the socket while
      * this method gets its value from this instance's config.
-     * @since 3.11.0
+     *
      * @return a clone of the suites, may be null
+     * @since 3.11.0
      */
     protected String[] getSuites() {
         return suites == null ? null : suites.clone();
@@ -677,7 +675,7 @@ public class FTPSClient extends FTPClient {
     }
 
     /**
-     * Returns true if the socket is set to use client mode in its first handshake. When the underlying {@link Socket} is not an {@link SSLSocket} instance,
+     * Gets whether the socket is set to use client mode in its first handshake. When the underlying {@link Socket} is not an {@link SSLSocket} instance,
      * returns false.
      *
      * @return true - If the socket should start its first handshake in "client" mode.
@@ -690,7 +688,7 @@ public class FTPSClient extends FTPClient {
     }
 
     /**
-     * Returns true if the socket will request client authentication. When the underlying {@link Socket} is not an {@link SSLSocket} instance, returns false.
+     * Gets whether the socket will request client authentication. When the underlying {@link Socket} is not an {@link SSLSocket} instance, returns false.
      *
      * @return true - If the server mode socket should request that the client authenticate itself.
      */
@@ -713,26 +711,28 @@ public class FTPSClient extends FTPClient {
     }
 
     /**
-     * Gets the use client mode flag. The {@link #getUseClientMode()} method gets the value from the socket while
+     * Tests the use client mode flag. The {@link #getUseClientMode()} method gets the value from the socket while
      * this method gets its value from this instance's config.
-     * @since 3.11.0
+     *
      * @return True If the socket should start its first handshake in "client" mode.
+     * @since 3.11.0
      */
     protected boolean isClientMode() {
         return isClientMode;
     }
 
     /**
-     * Gets whether a new SSL session may be established by this socket. Default true
-     * @since 3.11.0
+     * Tests whether a new SSL session may be established by this socket. Default true
+     *
      * @return True if session may be established
+     * @since 3.11.0
      */
     protected boolean isCreation() {
         return isCreation;
     }
 
     /**
-     * Return whether or not endpoint identification using the HTTPS algorithm on Java 1.7+ is enabled. The default behavior is for this to be disabled.
+     * Tests whether or not endpoint identification using the HTTPS algorithm on Java 1.7+ is enabled. The default behavior is for this to be disabled.
      *
      * This check is only performed on client mode connections.
      *
@@ -744,29 +744,32 @@ public class FTPSClient extends FTPClient {
     }
 
     /**
-     * Gets the security mode. (True - Implicit Mode / False - Explicit Mode)
-     * @since 3.11.0
+     * Tests the security mode. (True - Implicit Mode / False - Explicit Mode).
+     *
      * @return True if enabled, false if not.
+     * @since 3.11.0
      */
     protected boolean isImplicit() {
         return isImplicit;
     }
 
     /**
-     * Gets the need client auth flag. The {@link #getNeedClientAuth()} method gets the value from the socket while
+     * Tests the need client auth flag. The {@link #getNeedClientAuth()} method gets the value from the socket while
      * this method gets its value from this instance's config.
-     * @since 3.11.0
+     *
      * @return True if enabled, false if not.
+     * @since 3.11.0
      */
     protected boolean isNeedClientAuth() {
         return isNeedClientAuth;
     }
 
     /**
-     * Gets the want client auth flag. The {@link #getWantClientAuth()} method gets the value from the socket while
+     * Tests the want client auth flag. The {@link #getWantClientAuth()} method gets the value from the socket while
      * this method gets its value from this instance's config.
-     * @since 3.11.0
+     *
      * @return True if enabled, false if not.
+     * @since 3.11.0
      */
     protected boolean isWantClientAuth() {
         return isWantClientAuth;
@@ -797,7 +800,7 @@ public class FTPSClient extends FTPClient {
         if (getDataConnectionMode() == ACTIVE_LOCAL_DATA_CONNECTION_MODE) {
             // if no activePortRange was set (correctly) -> getActivePort() = 0
             // -> new ServerSocket(0) -> bind to any free local port
-            try (final ServerSocket server = _serverSocketFactory_.createServerSocket(getActivePort(), 1, getHostAddress())) {
+            try (ServerSocket server = _serverSocketFactory_.createServerSocket(getActivePort(), 1, getHostAddress())) {
                 // Try EPRT only if remote server is over IPv6, if not use PORT,
                 // because EPRT has no advantage over PORT on IPv4.
                 // It could even have the disadvantage,
@@ -994,7 +997,7 @@ public class FTPSClient extends FTPClient {
     }
 
     /**
-     * Controls which particular cipher suites are enabled for use on this connection. Called before server negotiation.
+     * Sets which particular cipher suites are enabled for use on this connection. Called before server negotiation.
      *
      * @param cipherSuites The cipher suites.
      */
@@ -1003,7 +1006,7 @@ public class FTPSClient extends FTPClient {
     }
 
     /**
-     * Controls which particular protocol versions are enabled for use on this connection. I perform setting before a server negotiation.
+     * Sets which particular protocol versions are enabled for use on this connection. I perform setting before a server negotiation.
      *
      * @param protocolVersions The protocol versions.
      */
@@ -1012,7 +1015,7 @@ public class FTPSClient extends FTPClient {
     }
 
     /**
-     * Controls whether a new SSL session may be established by this socket.
+     * Sets whether a new SSL session may be established by this socket.
      *
      * @param isCreation The established socket flag.
      */
@@ -1021,7 +1024,7 @@ public class FTPSClient extends FTPClient {
     }
 
     /**
-     * Automatic endpoint identification checking using the HTTPS algorithm is supported on Java 1.7+. The default behavior is for this to be disabled.
+     * Sets automatic endpoint identification checking using the HTTPS algorithm is supported on Java 1.7+. The default behavior is for this to be disabled.
      *
      * This check is only performed on client mode connections.
      *
@@ -1033,7 +1036,7 @@ public class FTPSClient extends FTPClient {
     }
 
     /**
-     * Override the default {@link HostnameVerifier} to use. The verifier is only used on client mode connections.
+     * Sets to override the default {@link HostnameVerifier} to use. The verifier is only used on client mode connections.
      *
      * @param newHostnameVerifier The HostnameVerifier implementation to set or {@code null} to disable.
      * @since 3.4
@@ -1053,7 +1056,7 @@ public class FTPSClient extends FTPClient {
     }
 
     /**
-     * Configures the socket to require client authentication.
+     * Sets the socket to require client authentication.
      *
      * @param isNeedClientAuth The need client auth flag.
      */
@@ -1062,7 +1065,7 @@ public class FTPSClient extends FTPClient {
     }
 
     /**
-     * Override the default {@link TrustManager} to use; if set to {@code null}, the default TrustManager from the JVM will be used.
+     * Sets to override the default {@link TrustManager} to use; if set to {@code null}, the default TrustManager from the JVM will be used.
      *
      * @param trustManager The TrustManager implementation to set, may be {@code null}
      * @see org.apache.commons.net.util.TrustManagerUtils
@@ -1072,7 +1075,7 @@ public class FTPSClient extends FTPClient {
     }
 
     /**
-     * Configures the socket to use client (or server) mode in its first handshake.
+     * Sets the socket to use client (or server) mode in its first handshake.
      *
      * @param isClientMode The use client mode flag.
      */
@@ -1081,7 +1084,7 @@ public class FTPSClient extends FTPClient {
     }
 
     /**
-     * Configures the socket to request client authentication, but only if such a request is appropriate to the cipher suite negotiated.
+     * Sets the socket to request client authentication, but only if such a request is appropriate to the cipher suite negotiated.
      *
      * @param isWantClientAuth The want client auth flag.
      */
