@@ -6,7 +6,7 @@
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -18,6 +18,7 @@
 package org.apache.commons.net.ntp;
 
 import java.net.DatagramPacket;
+import java.util.Arrays;
 
 /**
  * Implements {@link NtpV3Packet} to convert Java objects to and from the Network Time Protocol (NTP) data message header format described in RFC-1305.
@@ -79,7 +80,7 @@ public class NtpV3Impl implements NtpV3Packet {
 
     /**
      * Compares this object against the specified object. The result is {@code true} if and only if the argument is not {@code null} and is a
-     * <code>NtpV3Impl</code> object that contains the same values as this object.
+     * {@code NtpV3Impl} object that contains the same values as this object.
      *
      * @param obj the object to compare with.
      * @return {@code true} if the objects are the same; {@code false} otherwise.
@@ -94,11 +95,11 @@ public class NtpV3Impl implements NtpV3Packet {
             return false;
         }
         final NtpV3Impl other = (NtpV3Impl) obj;
-        return java.util.Arrays.equals(buf, other.buf);
+        return Arrays.equals(buf, other.buf);
     }
 
     /**
-     * Returns the datagram packet with the NTP details already filled in.
+     * Gets the datagram packet with the NTP details already filled in.
      *
      * @return a datagram packet.
      */
@@ -112,6 +113,8 @@ public class NtpV3Impl implements NtpV3Packet {
     }
 
     /**
+     * Gets 4 bytes as 32-bit int.
+     *
      * @return 4 bytes as 32-bit int
      */
     private int getInt(final int index) {
@@ -119,7 +122,7 @@ public class NtpV3Impl implements NtpV3Packet {
     }
 
     /**
-     * Returns leap indicator as defined in RFC-1305 which is a two-bit code: 0=no warning 1=last minute has 61 seconds 2=last minute has 59 seconds 3=alarm
+     * Gets leap indicator as defined in RFC-1305 which is a two-bit code: 0=no warning 1=last minute has 61 seconds 2=last minute has 59 seconds 3=alarm
      * condition (clock not synchronized)
      *
      * @return leap indicator as defined in RFC-1305.
@@ -140,7 +143,7 @@ public class NtpV3Impl implements NtpV3Packet {
     }
 
     /**
-     * Returns mode as defined in RFC-1305 which is a 3-bit integer whose value is indicated by the MODE_xxx parameters.
+     * Gets the mode as defined in RFC-1305 which is a 3-bit integer whose value is indicated by the MODE_xxx parameters.
      *
      * @return mode as defined in RFC-1305.
      */
@@ -150,7 +153,7 @@ public class NtpV3Impl implements NtpV3Packet {
     }
 
     /**
-     * Return human-readable name of message mode type as described in RFC 1305.
+     * Gets the human-readable name of message mode type as described in RFC 1305.
      *
      * @return mode name as string.
      */
@@ -160,7 +163,7 @@ public class NtpV3Impl implements NtpV3Packet {
     }
 
     /**
-     * Returns the {@code originate} time as defined in RFC-1305.
+     * Gets the {@code originate} time as defined in RFC-1305.
      *
      * @return the {@code originate} time. Never returns null.
      */
@@ -170,7 +173,7 @@ public class NtpV3Impl implements NtpV3Packet {
     }
 
     /**
-     * Returns poll interval as defined in RFC-1305, which is an eight-bit signed integer indicating the maximum interval between successive messages, in
+     * Gets the poll interval as defined in RFC-1305, which is an eight-bit signed integer indicating the maximum interval between successive messages, in
      * seconds to the nearest power of two (e.g. value of six indicates an interval of 64 seconds). The values that can appear in this field range from
      * NTP_MINPOLL to NTP_MAXPOLL inclusive.
      *
@@ -182,7 +185,7 @@ public class NtpV3Impl implements NtpV3Packet {
     }
 
     /**
-     * Returns precision as defined in RFC-1305 encoded as an 8-bit signed integer (seconds to the nearest power of two). Values normally range from -6 to -20.
+     * Gets the precision as defined in RFC-1305 encoded as an 8-bit signed integer (seconds to the nearest power of two). Values normally range from -6 to -20.
      *
      * @return precision as defined in RFC-1305.
      */
@@ -192,7 +195,7 @@ public class NtpV3Impl implements NtpV3Packet {
     }
 
     /**
-     * Returns {@code receive} timestamp as defined in RFC-1305.
+     * Gets the {@code receive} timestamp as defined in RFC-1305.
      *
      * @return the {@code receive} time. Never returns null.
      */
@@ -202,7 +205,7 @@ public class NtpV3Impl implements NtpV3Packet {
     }
 
     /**
-     * Returns the reference id as defined in RFC-1305, which is a 32-bit integer whose value is dependent on several criteria.
+     * Gets the reference id as defined in RFC-1305, which is a 32-bit integer whose value is dependent on several criteria.
      *
      * @return the reference id as defined in RFC-1305.
      */
@@ -212,7 +215,7 @@ public class NtpV3Impl implements NtpV3Packet {
     }
 
     /**
-     * Returns the reference id string. String cannot be null but value is dependent on the version of the NTP spec supported and stratum level. Value can be an
+     * Gets the reference id string. String cannot be null but value is dependent on the version of the NTP spec supported and stratum level. Value can be an
      * empty string, clock type string, IP address, or a hexadecimal string.
      *
      * @return the reference id string.
@@ -240,9 +243,9 @@ public class NtpV3Impl implements NtpV3Packet {
     }
 
     /**
-     * Returns the reference time as defined in RFC-1305.
+     * Gets the reference time as defined in RFC-1305.
      *
-     * @return the reference time as <code>TimeStamp</code> object. Never returns null.
+     * @return the reference time as {@code TimeStamp} object. Never returns null.
      */
     @Override
     public TimeStamp getReferenceTimeStamp() {
@@ -250,7 +253,7 @@ public class NtpV3Impl implements NtpV3Packet {
     }
 
     /**
-     * Return root delay as defined in RFC-1305, which is the total roundtrip delay to the primary reference source, in seconds. Values can take positive and
+     * Gets the root delay as defined in RFC-1305, which is the total roundtrip delay to the primary reference source, in seconds. Values can take positive and
      * negative values, depending on clock precision and skew.
      *
      * @return root delay as defined in RFC-1305.
@@ -261,8 +264,8 @@ public class NtpV3Impl implements NtpV3Packet {
     }
 
     /**
-     * Return root delay as defined in RFC-1305 in milliseconds, which is the total roundtrip delay to the primary reference source, in seconds. Values can take
-     * positive and negative values, depending on clock precision and skew.
+     * Gets the root delay as defined in RFC-1305 in milliseconds, which is the total roundtrip delay to the primary reference source, in seconds. Values can
+     * take positive and negative values, depending on clock precision and skew.
      *
      * @return root delay in milliseconds
      */
@@ -273,7 +276,7 @@ public class NtpV3Impl implements NtpV3Packet {
     }
 
     /**
-     * Returns root dispersion as defined in RFC-1305.
+     * Gets the root dispersion as defined in RFC-1305.
      *
      * @return root dispersion.
      */
@@ -283,7 +286,7 @@ public class NtpV3Impl implements NtpV3Packet {
     }
 
     /**
-     * Returns root dispersion (as defined in RFC-1305) in milliseconds.
+     * Gets the root dispersion (as defined in RFC-1305) in milliseconds.
      *
      * @return root dispersion in milliseconds
      */
@@ -294,7 +297,7 @@ public class NtpV3Impl implements NtpV3Packet {
     }
 
     /**
-     * Returns root dispersion (as defined in RFC-1305) in milliseconds as double precision value.
+     * Gets the root dispersion (as defined in RFC-1305) in milliseconds as double precision value.
      *
      * @return root dispersion in milliseconds
      */
@@ -305,7 +308,7 @@ public class NtpV3Impl implements NtpV3Packet {
     }
 
     /**
-     * Returns Stratum as defined in RFC-1305, which indicates the stratum level of the local clock, with values defined as follows: 0=unspecified, 1=primary
+     * Gets the Stratum as defined in RFC-1305, which indicates the stratum level of the local clock, with values defined as follows: 0=unspecified, 1=primary
      * ref clock, and all others a secondary reference (via NTP).
      *
      * @return Stratum level as defined in RFC-1305.
@@ -316,7 +319,7 @@ public class NtpV3Impl implements NtpV3Packet {
     }
 
     /**
-     * Gets NTP Timestamp at specified starting index.
+     * Gets the NTP Timestamp at specified starting index.
      *
      * @param index index into data array
      * @return TimeStamp object for 64 bits starting at index
@@ -326,7 +329,7 @@ public class NtpV3Impl implements NtpV3Packet {
     }
 
     /**
-     * Returns the {@code transmit} timestamp as defined in RFC-1305.
+     * Gets the {@code transmit} timestamp as defined in RFC-1305.
      *
      * @return the {@code transmit} timestamp as defined in RFC-1305. Never returns a null object.
      */
@@ -336,7 +339,7 @@ public class NtpV3Impl implements NtpV3Packet {
     }
 
     /**
-     * Return type of time packet. The values (e.g. NTP, TIME, ICMP, ...) correspond to the protocol used to obtain the timing information.
+     * Gets the type of time packet. The values (e.g. NTP, TIME, ICMP, ...) correspond to the protocol used to obtain the timing information.
      *
      * @return packet type string identifier which in this case is "NTP".
      */
@@ -346,7 +349,7 @@ public class NtpV3Impl implements NtpV3Packet {
     }
 
     /**
-     * Returns NTP version number as defined in RFC-1305.
+     * Gets the NTP version number as defined in RFC-1305.
      *
      * @return NTP version number.
      */
@@ -363,7 +366,7 @@ public class NtpV3Impl implements NtpV3Packet {
      */
     @Override
     public int hashCode() {
-        return java.util.Arrays.hashCode(buf);
+        return Arrays.hashCode(buf);
     }
 
     private String idAsHex() {
@@ -450,7 +453,7 @@ public class NtpV3Impl implements NtpV3Packet {
     }
 
     /**
-     * Sets originate timestamp given NTP TimeStamp object. If <code>ts</code> is null then zero time is used.
+     * Sets originate timestamp given NTP TimeStamp object. If {@code ts} is null then zero time is used.
      *
      * @param ts NTP timestamp
      */
@@ -481,7 +484,7 @@ public class NtpV3Impl implements NtpV3Packet {
     }
 
     /**
-     * Sets receive timestamp given NTP TimeStamp object. If <code>ts</code> is null then zero time is used.
+     * Sets receive timestamp given NTP TimeStamp object. If {@code ts} is null then zero time is used.
      *
      * @param ts timestamp
      */
@@ -501,7 +504,7 @@ public class NtpV3Impl implements NtpV3Packet {
     }
 
     /**
-     * Sets Reference time with NTP timestamp. If <code>ts</code> is null then zero time is used.
+     * Sets Reference time with NTP timestamp. If {@code ts} is null then zero time is used.
      *
      * @param ts NTP timestamp
      */
@@ -560,7 +563,7 @@ public class NtpV3Impl implements NtpV3Packet {
     }
 
     /**
-     * Sets transmit time with NTP timestamp. If <code>ts</code> is null then zero time is used.
+     * Sets transmit time with NTP timestamp. If {@code ts} is null then zero time is used.
      *
      * @param ts NTP timestamp
      */
@@ -586,7 +589,7 @@ public class NtpV3Impl implements NtpV3Packet {
      */
     @Override
     public String toString() {
-        return "[" + "version:" + getVersion() + ", mode:" + getMode() + ", poll:" + getPoll() + ", precision:" + getPrecision() + ", delay:" + getRootDelay()
+        return "[version:" + getVersion() + ", mode:" + getMode() + ", poll:" + getPoll() + ", precision:" + getPrecision() + ", delay:" + getRootDelay()
                 + ", dispersion(ms):" + getRootDispersionInMillisDouble() + ", id:" + getReferenceIdString() + ", xmitTime:"
                 + getTransmitTimeStamp().toDateString() + " ]";
     }
