@@ -6,7 +6,7 @@
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -30,13 +30,23 @@ final class TelnetInputStream extends BufferedInputStream implements Runnable {
     private static final int WOULD_BLOCK = -2;
 
     // TODO should these be private enums?
-    static final int STATE_DATA = 0, STATE_IAC = 1, STATE_WILL = 2, STATE_WONT = 3, STATE_DO = 4, STATE_DONT = 5, STATE_SB = 6, STATE_SE = 7, STATE_CR = 8,
-            STATE_IAC_SB = 9;
-
+    static final int STATE_DATA = 0;
+    static final int STATE_IAC = 1;
+    static final int STATE_WILL = 2;
+    static final int STATE_WONT = 3;
+    static final int STATE_DO = 4;
+    static final int STATE_DONT = 5;
+    static final int STATE_SB = 6;
+    static final int STATE_SE = 7;
+    static final int STATE_CR = 8;
+    static final int STATE_IAC_SB = 9;
     private boolean hasReachedEOF; // @GuardedBy("queue")
     private volatile boolean isClosed;
     private boolean readIsWaiting;
-    private int receiveState, queueHead, queueTail, bytesAvailable;
+    private int receiveState;
+    private int queueHead;
+    private int queueTail;
+    private int bytesAvailable;
     private final int[] queue;
     private final TelnetClient client;
     private final Thread thread;
@@ -117,7 +127,7 @@ final class TelnetInputStream extends BufferedInputStream implements Runnable {
     }
 
     // synchronized(client) critical sections are to protect against
-    // TelnetOutputStream writing through the telnet client at same time
+    // TelnetOutputStream writing through the Telnet client at same time
     // as a processDo/Will/etc. command invoked from TelnetInputStream
     // tries to write. Returns true if buffer was previously empty.
     private boolean processChar(final int ch) throws InterruptedException {
@@ -196,10 +206,9 @@ final class TelnetInputStream extends BufferedInputStream implements Runnable {
 
                         do {
                             try {
-                                if ((ch = read(mayBlock)) < 0) { // must be EOF
-                                    if (ch != WOULD_BLOCK) {
-                                        return ch;
-                                    }
+                                if ((ch = read(mayBlock)) < 0 && ch != WOULD_BLOCK) {
+                                    // must be EOF
+                                    return ch;
                                 }
                             } catch (final InterruptedIOException e) {
                                 synchronized (queue) {
@@ -251,13 +260,13 @@ final class TelnetInputStream extends BufferedInputStream implements Runnable {
                     queue.notify();
                 }
 
-                return ch;
+                return ch; // NOPMD TODO?
             }
         }
     }
 
     // synchronized(client) critical sections are to protect against
-    // TelnetOutputStream writing through the telnet client at same time
+    // TelnetOutputStream writing through the Telnet client at same time
     // as a processDo/Will/etc. command invoked from TelnetInputStream
     // tries to write.
     /**
@@ -297,7 +306,7 @@ final class TelnetInputStream extends BufferedInputStream implements Runnable {
             switch (receiveState) {
 
             case STATE_CR:
-                if (ch == '\0') {
+                if (ch == Telnet.NUL) {
                     // Strip null
                     continue;
                 }
@@ -306,7 +315,7 @@ final class TelnetInputStream extends BufferedInputStream implements Runnable {
 
                 // Handle as normal data by falling through to _STATE_DATA case
 
-                //$FALL-THROUGH$
+                // falls through$
             case STATE_DATA:
                 if (ch == TelnetCommand.IAC) {
                     receiveState = STATE_IAC;
@@ -423,7 +432,7 @@ final class TelnetInputStream extends BufferedInputStream implements Runnable {
             /* TERMINAL-TYPE option (end) */
             }
 
-            break;
+            break; // NOPMD TODO?
         }
 
         return ch;
