@@ -6,7 +6,7 @@
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -32,13 +32,13 @@ import org.apache.commons.net.io.ToNetASCIIInputStream;
  * The TFTPClient class encapsulates all the aspects of the TFTP protocol necessary to receive and send files through TFTP. It is derived from the
  * {@link org.apache.commons.net.tftp.TFTP} because it is more convenient than using aggregation, and as a result exposes the same set of methods to allow you
  * to deal with the TFTP protocol directly. However, almost every user should only be concerend with the the
- * {@link org.apache.commons.net.DatagramSocketClient#open open() }, {@link org.apache.commons.net.DatagramSocketClient#close close() }, {@link #sendFile
- * sendFile() }, and {@link #receiveFile receiveFile() } methods. Additionally, the {@link #setMaxTimeouts setMaxTimeouts() } and
- * {@link org.apache.commons.net.DatagramSocketClient#setDefaultTimeout setDefaultTimeout() } methods may be of importance for performance tuning.
+ * {@link org.apache.commons.net.DatagramSocketClient#open open()}, {@link org.apache.commons.net.DatagramSocketClient#close close()}, {@link #sendFile
+ * sendFile()}, and {@link #receiveFile receiveFile()} methods. Additionally, the {@link #setMaxTimeouts setMaxTimeouts()} and
+ * {@link org.apache.commons.net.DatagramSocketClient#setDefaultTimeout setDefaultTimeout()} methods may be of importance for performance tuning.
  * <p>
  * Details regarding the TFTP protocol and the format of TFTP packets can be found in RFC 783. But the point of these classes is to keep you from having to
  * worry about the internals.
- *
+ * </p>
  *
  * @see TFTP
  * @see TFTPPacket
@@ -70,7 +70,7 @@ public class TFTPClient extends TFTP {
     }
 
     /**
-     * Returns the maximum number of times a {@code receive} attempt is allowed to timeout before ending attempts to retry the {@code receive} and failing.
+     * Gets the maximum number of times a {@code receive} attempt is allowed to timeout before ending attempts to retry the {@code receive} and failing.
      *
      * @return The maximum number of timeouts allowed.
      */
@@ -79,14 +79,18 @@ public class TFTPClient extends TFTP {
     }
 
     /**
-     * @return The number of bytes received in the ongoing download
+     * Gets the number of bytes received in the ongoing download.
+     *
+     * @return The number of bytes received in the ongoing download.
      */
     public long getTotalBytesReceived() {
         return totalBytesReceived;
     }
 
     /**
-     * @return The number of bytes sent in the ongoing download
+     * Gets the number of bytes sent in the ongoing download.
+     *
+     * @return The number of bytes sent in the ongoing download.
      */
     public long getTotalBytesSent() {
         return totalBytesSent;
@@ -128,7 +132,7 @@ public class TFTPClient extends TFTP {
 
         totalBytesReceived = 0;
 
-        if (mode == TFTP.ASCII_MODE) {
+        if (mode == ASCII_MODE) {
             output = new FromNetASCIIOutputStream(output);
         }
 
@@ -296,7 +300,7 @@ public class TFTPClient extends TFTP {
 
         totalBytesSent = 0L;
 
-        if (mode == TFTP.ASCII_MODE) {
+        if (mode == ASCII_MODE) {
             input = new ToNetASCIIInputStream(input);
         }
 
