@@ -6,7 +6,7 @@
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -27,7 +27,7 @@ import java.net.InetAddress;
  * worry about the internals. Additionally, only very few people should have to care about any of the TFTPPacket classes or derived classes. Almost all users
  * should only be concerned with the {@link org.apache.commons.net.tftp.TFTPClient} class {@link org.apache.commons.net.tftp.TFTPClient#receiveFile
  * receiveFile()} and {@link org.apache.commons.net.tftp.TFTPClient#sendFile sendFile()} methods.
- *
+ * </p>
  *
  * @see TFTPPacket
  * @see TFTPRequestPacket
@@ -45,7 +45,7 @@ public final class TFTPWriteRequestPacket extends TFTPRequestPacket {
      * @throws TFTPPacketException If the datagram isn't a valid TFTP request packet.
      */
     TFTPWriteRequestPacket(final DatagramPacket datagram) throws TFTPPacketException {
-        super(TFTPPacket.WRITE_REQUEST, datagram);
+        super(WRITE_REQUEST, datagram);
     }
 
     /**
@@ -57,7 +57,7 @@ public final class TFTPWriteRequestPacket extends TFTPRequestPacket {
      * @param mode        The requested transfer mode. This should be on of the TFTP class MODE constants (e.g., TFTP.NETASCII_MODE).
      */
     public TFTPWriteRequestPacket(final InetAddress destination, final int port, final String fileName, final int mode) {
-        super(destination, port, TFTPPacket.WRITE_REQUEST, fileName, mode);
+        super(destination, port, WRITE_REQUEST, fileName, mode);
     }
 
     /**
