@@ -6,7 +6,7 @@
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -36,6 +36,7 @@ import org.apache.ftpserver.ftplet.UserManager;
 import org.apache.ftpserver.listener.ListenerFactory;
 import org.apache.ftpserver.ssl.SslConfiguration;
 import org.apache.ftpserver.ssl.SslConfigurationFactory;
+import org.apache.ftpserver.usermanager.Md5PasswordEncryptor;
 import org.apache.ftpserver.usermanager.PropertiesUserManagerFactory;
 import org.apache.ftpserver.usermanager.impl.BaseUser;
 import org.junit.Assert;
@@ -66,7 +67,6 @@ public abstract class AbstractFtpsTest {
     /**
      * Returns the test directory as a String.
      * @param defaultHome A default value.
-     *
      * @return the test directory as a String
      */
     protected static String getTestHomeDirectory(final String defaultHome) {
@@ -82,8 +82,8 @@ public abstract class AbstractFtpsTest {
      * @param defaultHome default home folder
      * @throws FtpException Thrown when the FTP classes cannot fulfill a request.
      */
-    protected synchronized static void setupServer(final boolean implicit, final String userPropertiesResource, final String serverJksResourceResource, final String defaultHome)
-            throws FtpException {
+    protected static synchronized void setupServer(final boolean implicit, final String userPropertiesResource, final String serverJksResourceResource,
+            final String defaultHome) throws FtpException {
         if (EmbeddedFtpServer != null) {
             return;
         }
@@ -91,6 +91,8 @@ public abstract class AbstractFtpsTest {
         SocketPort = 0;
         final FtpServerFactory serverFactory = new FtpServerFactory();
         final PropertiesUserManagerFactory propertiesUserManagerFactory = new PropertiesUserManagerFactory();
+        // TODO Update to SHA512
+        propertiesUserManagerFactory.setPasswordEncryptor(new Md5PasswordEncryptor());
         final URL userPropsResource = ClassLoader.getSystemClassLoader().getResource(userPropertiesResource);
         Assert.assertNotNull(userPropertiesResource, userPropsResource);
         propertiesUserManagerFactory.setUrl(userPropsResource);
