@@ -6,7 +6,7 @@
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -23,20 +23,15 @@ import org.apache.commons.net.ftp.FTPFileEntryParser;
 
 /**
  */
-public class NetwareFTPEntryParserTest extends FTPParseTestFramework {
+public class NetwareFTPEntryParserTest extends AbstractFTPParseTest {
 
-    private static final String[] badsamples = {
-        "a [-----F--] SCION_SYS                         512 Apr 13 23:52 SYS",
-            "d [----AF--]          0                        512 10-04-2001 _ADMIN"
-    };
+    private static final String[] badsamples = { "a [-----F--] SCION_SYS                         512 Apr 13 23:52 SYS",
+            "d [----AF--]          0                        512 10-04-2001 _ADMIN" };
 
-    private static final String [] goodsamples = {
-        "d [-----F--] SCION_SYS                         512 Apr 13 23:52 SYS",
-        "d [----AF--]          0                        512 Feb 22 17:32 _ADMIN",
-        "d [-W---F--] SCION_VOL2                        512 Apr 13 23:12 VOL2",
-        "- [RWCEAFMS] rwinston                        19968 Mar 12 15:20 Executive Summary.doc",
-        "d [RWCEAFMS] rwinston                          512 Nov 24  2005 Favorites"
-    };
+    private static final String[] goodsamples = { "d [-----F--] SCION_SYS                         512 Apr 13 23:52 SYS",
+            "d [----AF--]          0                        512 Feb 22 17:32 _ADMIN", "d [-W---F--] SCION_VOL2                        512 Apr 13 23:12 VOL2",
+            "- [RWCEAFMS] rwinston                        19968 Mar 12 15:20 Executive Summary.doc",
+            "d [RWCEAFMS] rwinston                          512 Nov 24  2005 Favorites" };
 
     public NetwareFTPEntryParserTest(final String name) {
         super(name);
@@ -57,6 +52,11 @@ public class NetwareFTPEntryParserTest extends FTPParseTestFramework {
         return new NetwareFTPEntryParser();
     }
 
+    @Override
+    public void testDefaultPrecision() {
+        testPrecision("d [RWCEAFMS] rwinston                          512 Nov 24  2005 Favorites", CalendarUnit.DAY_OF_MONTH);
+    }
+
     @Override
     public void testParseFieldsOnDirectory() throws Exception {
         final String reply = "d [-W---F--] testUser                        512 Apr 13 23:12 testFile";
@@ -77,12 +77,10 @@ public class NetwareFTPEntryParserTest extends FTPParseTestFramework {
         cal.set(Calendar.MILLISECOND, 0);
         cal.set(Calendar.YEAR, f.getTimestamp().get(Calendar.YEAR));
 
-        assertEquals(df.format(cal.getTime()), df.format(f.getTimestamp()
-                .getTime()));
+        assertEquals(df.format(cal.getTime()), df.format(f.getTimestamp().getTime()));
 
     }
 
-
     @Override
     public void testParseFieldsOnFile() throws Exception {
         final String reply = "- [R-CEAFMS] rwinston                        19968 Mar 12 15:20 Document name with spaces.doc";
@@ -99,16 +97,9 @@ public class NetwareFTPEntryParserTest extends FTPParseTestFramework {
         assertFalse(f.hasPermission(FTPFile.USER_ACCESS, FTPFile.WRITE_PERMISSION));
     }
 
-    @Override
-    public void testDefaultPrecision() {
-        testPrecision("d [RWCEAFMS] rwinston                          512 Nov 24  2005 Favorites", CalendarUnit.DAY_OF_MONTH);
-    }
-
     @Override
     public void testRecentPrecision() {
         testPrecision("- [RWCEAFMS] rwinston                        19968 Mar 12 15:20 Executive Summary.doc", CalendarUnit.MINUTE);
     }
 
 }
-
-
