@@ -6,7 +6,7 @@
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -24,27 +24,28 @@ import java.io.OutputStream;
  * thread.
  */
 public class TelnetTestResponder implements Runnable {
-    InputStream _is;
-    OutputStream _os;
-    String _inputs[], _outputs[];
-    long _timeout;
+    InputStream in;
+    OutputStream out;
+    String inputs[];
+    String outputs[];
+    long timeout;
 
     /**
      * Constructs a new instance. Starts a new thread for the reader.
      * <p>
      *
-     * @param is      - InputStream on which to read.
-     * @param os      - OutputStream on which to answer.
-     * @param inputs  - Array of waited for Strings.
-     * @param outputs - Array of answers.
-     * @param timeout - milliseconds
+     * @param is        InputStream on which to read.
+     * @param os        OutputStream on which to answer.
+     * @param inputs    Array of waited for Strings.
+     * @param outputs   Array of answers.
+     * @param timeout   milliseconds
      */
     public TelnetTestResponder(final InputStream is, final OutputStream os, final String inputs[], final String outputs[], final long timeout) {
-        _is = is;
-        _os = os;
-        _timeout = timeout;
-        _inputs = inputs;
-        _outputs = outputs;
+        this.in = is;
+        this.out = os;
+        this.timeout = timeout;
+        this.inputs = inputs;
+        this.outputs = outputs;
         final Thread reader = new Thread(this);
 
         reader.start();
@@ -61,15 +62,15 @@ public class TelnetTestResponder implements Runnable {
 
         try {
             final StringBuilder readbytes = new StringBuilder();
-            while (!result && System.currentTimeMillis() - starttime < _timeout) {
-                if (_is.available() > 0) {
-                    final int ret_read = _is.read(buffer);
+            while (!result && System.currentTimeMillis() - starttime < timeout) {
+                if (in.available() > 0) {
+                    final int ret_read = in.read(buffer);
                     readbytes.append(new String(buffer, 0, ret_read));
 
-                    for (int ii = 0; ii < _inputs.length; ii++) {
-                        if (readbytes.indexOf(_inputs[ii]) >= 0) {
+                    for (int ii = 0; ii < inputs.length; ii++) {
+                        if (readbytes.indexOf(inputs[ii]) >= 0) {
                             Thread.sleep(1000 * ii);
-                            _os.write(_outputs[ii].getBytes());
+                            out.write(outputs[ii].getBytes());
                             result = true;
                         }
                     }
